diff --git a/Aura.lua b/Aura.lua
index d521df6..f04e451 100644
--- a/Aura.lua
+++ b/Aura.lua
@@ -69,6 +69,19 @@ end
-- ------------------------
+-- TOOLTIP HANDLERS
+-- ------------------------
+local function OnMouseEnter(aura)
+ InitializeTooltip(InformationTooltip, aura, BOTTOMLEFT, 0, - 2, TOPLEFT)
+ SetTooltipText(InformationTooltip, aura.auraName)
+end
+
+local function OnMouseExit()
+ ClearTooltip(InformationTooltip)
+end
+
+
+-- ------------------------
-- TIMER UPDATE HANDLER
do ------------------------
local RATE = Srendarr.AURA_UPDATE_RATE
@@ -319,6 +332,23 @@ function Aura:Configure(settings)
self.timer:SetColor(settings.timerColour[1], settings.timerColour[2], settings.timerColour[3], settings.timerColour[4])
self.timer:SetVerticalAlignment(TEXT_ALIGN_BOTTOM)
+ -- configure tooltip control
+ if (settings.style == AURA_STYLE_ICON and settings.enableTooltips) then -- only in icon mode
+ if (not self:GetHandler('OnMouseEnter')) then
+ self:SetHandler('OnMouseEnter', OnMouseEnter)
+ self:SetHandler('OnMouseExit', OnMouseExit)
+ end
+
+ self:SetMouseEnabled(true)
+ else
+ self:SetMouseEnabled(false)
+
+ if (self:GetHandler('OnMouseEnter')) then
+ self:SetHandler('OnMouseEnter', nil)
+ self:SetHandler('OnMouseExit', nil)
+ end
+ end
+
if (settings.style == AURA_STYLE_FULL) then -- full style, must be growing up or down
-- configure icon
self:SetTexture([[/esoui/art/actionbar/abilityframe64_up.dds]])
diff --git a/Core.lua b/Core.lua
index 4a8a176..45a6825 100644
--- a/Core.lua
+++ b/Core.lua
@@ -2,7 +2,7 @@
Srendarr - Aura (Buff & Debuff) Tracker
----------------------------------------------------------
*
- * Version 2.1.5
+ * Version 2.1.6
* Kith, Garkin, silentgecko
*
*
@@ -12,7 +12,7 @@ local L = Srendarr:GetLocale()
Srendarr.name = 'Srendarr'
Srendarr.slash = '/srendarr'
-Srendarr.version = '2.1.5'
+Srendarr.version = '2.1.6'
Srendarr.versionDB = 3
Srendarr.displayFrames = {}
@@ -182,6 +182,7 @@ do ------------------------
local GetAbilityName = GetAbilityName
local GetAbilityDuration = GetAbilityDuration
local GetAbilityDescription = GetAbilityDescription
+ local IsAbilityPassive = IsAbilityPassive
local fakeAuras = Srendarr.fakeAuras
@@ -194,7 +195,7 @@ do ------------------------
local compareName
for id = 1, 100000 do -- scan all abilityIDs looking for this auraName
- if (DoesAbilityExist(id) and GetAbilityDuration(id) > 0) then
+ if (DoesAbilityExist(id) and (GetAbilityDuration(id) > 0 or not IsAbilityPassive(id))) then
compareName = str_gsub(GetAbilityName(id), '%^%a?', '') -- strip out any control characters from the ability name
if (compareName == auraName) then -- matching ability with a duration (no toggles or passives in prominence)
diff --git a/Defaults.lua b/Defaults.lua
index bd4643f..aa3be14 100644
--- a/Defaults.lua
+++ b/Defaults.lua
@@ -124,6 +124,7 @@ local defaults = {
auraPadding = 3,
auraSort = Srendarr.AURA_SORT_TIMEASC, -- NAME|TIME|CAST + ASC|DESC
highlightToggled = true, -- shows the same 'toggled on' highlight action buttons do on toggles
+ enableTooltips = false, -- show mouseover tooltip for auraName in ICON mode
nameFont = 'Univers 67',
nameStyle = 'soft-shadow-thick',
nameSize = 16,
@@ -149,6 +150,7 @@ local defaults = {
auraPadding = 3,
auraSort = Srendarr.AURA_SORT_TIMEASC, -- NAME|TIME|CAST + ASC|DESC
highlightToggled = true, -- shows the same 'toggled on' highlight action buttons do on toggles
+ enableTooltips = false, -- show mouseover tooltip for auraName in ICON mode
nameFont = 'Univers 67',
nameStyle = 'soft-shadow-thick',
nameSize = 16,
@@ -174,6 +176,7 @@ local defaults = {
auraPadding = 3,
auraSort = Srendarr.AURA_SORT_TIMEASC, -- NAME|TIME|CAST + ASC|DESC
highlightToggled = true, -- shows the same 'toggled on' highlight action buttons do on toggles
+ enableTooltips = false, -- show mouseover tooltip for auraName in ICON mode
nameFont = 'Univers 67',
nameStyle = 'soft-shadow-thick',
nameSize = 16,
@@ -199,6 +202,7 @@ local defaults = {
auraPadding = 3,
auraSort = Srendarr.AURA_SORT_TIMEASC, -- NAME|TIME|CAST + ASC|DESC
highlightToggled = true, -- shows the same 'toggled on' highlight action buttons do on toggles
+ enableTooltips = false, -- show mouseover tooltip for auraName in ICON mode
nameFont = 'Univers 67',
nameStyle = 'soft-shadow-thick',
nameSize = 16,
@@ -224,6 +228,7 @@ local defaults = {
auraPadding = 4,
auraSort = Srendarr.AURA_SORT_TIMEASC, -- NAME|TIME|CAST + ASC|DESC
highlightToggled = true, -- shows the same 'toggled on' highlight action buttons do on toggles
+ enableTooltips = false, -- show mouseover tooltip for auraName in ICON mode
nameFont = 'Univers 67',
nameStyle = 'soft-shadow-thick',
nameSize = 16,
@@ -249,6 +254,7 @@ local defaults = {
auraPadding = 4,
auraSort = Srendarr.AURA_SORT_TIMEASC, -- NAME|TIME|CAST + ASC|DESC
highlightToggled = true, -- shows the same 'toggled on' highlight action buttons do on toggles
+ enableTooltips = false, -- show mouseover tooltip for auraName in ICON mode
nameFont = 'Univers 67',
nameStyle = 'soft-shadow-thick',
nameSize = 16,
@@ -274,6 +280,7 @@ local defaults = {
auraPadding = 4,
auraSort = Srendarr.AURA_SORT_TIMEASC, -- NAME|TIME|CAST + ASC|DESC
highlightToggled = true, -- shows the same 'toggled on' highlight action buttons do on toggles
+ enableTooltips = false, -- show mouseover tooltip for auraName in ICON mode
nameFont = 'Univers 67',
nameStyle = 'soft-shadow-thick',
nameSize = 16,
@@ -299,6 +306,7 @@ local defaults = {
auraPadding = 4,
auraSort = Srendarr.AURA_SORT_TIMEASC, -- NAME|TIME|CAST + ASC|DESC
highlightToggled = true, -- shows the same 'toggled on' highlight action buttons do on toggles
+ enableTooltips = false, -- show mouseover tooltip for auraName in ICON mode
nameFont = 'Univers 67',
nameStyle = 'soft-shadow-thick',
nameSize = 16,
diff --git a/Locales/Local_en.lua b/Locales/Local_en.lua
index d16e48a..6fe887c 100644
--- a/Locales/Local_en.lua
+++ b/Locales/Local_en.lua
@@ -243,6 +243,9 @@ L.DisplayFrame_Sort = 'Aura Sorting Order'
L.DisplayFrame_SortTip = 'Set how auras are sorted. Either by alphabetical name, remaining duration or by the order in which they were cast; whether this order is ascending or descending can also be set.\n\nWhen sorting by duration, any passives or toggled abilities will be sorted by name and shown closest to the anchor (ascending), or furthest from the anchor (descending), with timed abilities coming before (or after) them.'
L.DisplayFrame_Highlight = 'Toggled Aura Icon Highlight'
L.DisplayFrame_HighlightTip = 'Set whether toggled auras have their icon highlighted to help distinguish from passive auras.\n\nNot available in the |cffd100Mini|r style as no icon is shown.'
+L.DisplayFrame_Tooltips = 'Enable Aura Name Tooltips'
+L.DisplayFrame_TooltipsTip = 'Set whether to allow mouseover tooltip display for an aura\'s name when in the |cffd100Icon Only|r style.'
+L.DisplayFrame_TooltipsWarn = 'Tooltips must be temporarily disabled for movement of the Display Window, or the tooltips will block movement.'
-- settings: display frames (name)
L.DisplayFrame_NameHeader = 'Ability Name Text'
-- settings: display frames (timer)
diff --git a/Locales/Local_fr.lua b/Locales/Local_fr.lua
index a97968c..c22cad2 100644
--- a/Locales/Local_fr.lua
+++ b/Locales/Local_fr.lua
@@ -243,6 +243,9 @@ L.DisplayFrame_Sort = 'Ordre de tri des effets'
L.DisplayFrame_SortTip = 'Définissez comment les effets sont triés. Soit par ordre alphabétique, soit par durée restante ou dans l\'ordre où ils ont atés castés.\n\nLorsque vous triez par durée, tous les passifs et effets continus seront triés par nom et seront affichés en début ou en fin de pile selon l\'ordre de tri, avec les compétences temporaires listées ensuite ou avant.'
L.DisplayFrame_Highlight = 'Mise en surbrillance des icones d\'effet continu'
L.DisplayFrame_HighlightTip = 'Définir si les effets continus doivent être mis en surbrillance pour mieux les distinguer des effets passifs.\n\nNon disponible dans le mode |cffd100Minimal|r.'
+
+
+
-- settings: display frames (name)
L.DisplayFrame_NameHeader = 'Nom de la compétence'
-- settings: display frames (timer)
diff --git a/Locales/Local_ru.lua b/Locales/Local_ru.lua
index 224f01f..31ddd03 100644
--- a/Locales/Local_ru.lua
+++ b/Locales/Local_ru.lua
@@ -243,6 +243,9 @@ L.Time_Hours = '%dù'
+
+
+
-- settings: display frames (name)
-- settings: display frames (timer)
diff --git a/Srendarr.txt b/Srendarr.txt
index 24f7ba0..a640d13 100644
--- a/Srendarr.txt
+++ b/Srendarr.txt
@@ -1,6 +1,6 @@
## Title: |c67b1e9S|c4779ce'rendarr|r
## Description: Adds graphical tracking of buffs and debuffs on both yourself and others in a manner that meshes with the stock interface theme.
-## Version: 2.1.5
+## Version: 2.1.6
## Author: Kith, |cEFEBBEGarkin, silentgecko|r
## APIVersion: 100014
## SavedVariables: SrendarrDB
diff --git a/Settings.lua b/Settings.lua
index ae7ad03..9dd719c 100644
--- a/Settings.lua
+++ b/Settings.lua
@@ -1652,7 +1652,7 @@ tabPanelData = {
-- DISPLAY FRAME SETTINGS
-- -----------------------
[10] = {
- [1] = {
+ {
type = 'slider',
name = L.DisplayFrame_Alpha,
tooltip = L.DisplayFrame_AlphaTip,
@@ -1668,7 +1668,7 @@ tabPanelData = {
Srendarr.displayFrames[currentDisplayFrame].displayAlpha = v / 100
end,
},
- [2] = {
+ {
type = 'slider',
name = L.DisplayFrame_Scale,
tooltip = L.DisplayFrame_ScaleTip,
@@ -1686,11 +1686,11 @@ tabPanelData = {
-- -----------------------
-- AURA DISPLAY SETTINGS
-- -----------------------
- [3] = {
+ {
type = 'header',
name = L.DisplayFrame_AuraHeader,
},
- [4] = {
+ {
type = 'dropdown',
name = L.DisplayFrame_Style,
tooltip = L.DisplayFrame_StyleTip,
@@ -1706,7 +1706,7 @@ tabPanelData = {
ConfigurePanelDisplayFrame(true) -- changing this changes a lot of the following options
end,
},
- [5] = { -- auraGrowth FULL, MINI
+ { -- auraGrowth FULL, MINI
type = 'dropdown',
name = L.DisplayFrame_Growth,
tooltip = L.DisplayFrame_GrowthTip,
@@ -1722,7 +1722,7 @@ tabPanelData = {
end,
hideOnStyle = {[AURA_STYLE_FULL] = false, [AURA_STYLE_ICON] = true, [AURA_STYLE_MINI] = false}
},
- [6] = { -- auraGrowth ICON
+ { -- auraGrowth ICON
type = 'dropdown',
name = L.DisplayFrame_Growth,
tooltip = L.DisplayFrame_GrowthTip,
@@ -1738,7 +1738,7 @@ tabPanelData = {
end,
hideOnStyle = {[AURA_STYLE_FULL] = true, [AURA_STYLE_ICON] = false, [AURA_STYLE_MINI] = true}
},
- [7] = { -- auraPadding FULL, ICON, MINI
+ { -- auraPadding FULL, ICON, MINI
type = 'slider',
name = L.DisplayFrame_Padding,
tooltip = L.DisplayFrame_PaddingTip,
@@ -1755,7 +1755,7 @@ tabPanelData = {
end,
hideOnStyle = {[AURA_STYLE_FULL] = false, [AURA_STYLE_ICON] = false, [AURA_STYLE_MINI] = false}
},
- [8] = { -- auraSort FULL, ICON, MINI
+ { -- auraSort FULL, ICON, MINI
type = 'dropdown',
name = L.DisplayFrame_Sort,
tooltip = L.DisplayFrame_SortTip,
@@ -1771,7 +1771,7 @@ tabPanelData = {
end,
hideOnStyle = {[AURA_STYLE_FULL] = false, [AURA_STYLE_ICON] = false, [AURA_STYLE_MINI] = false}
},
- [9] = { -- highlightToggled FULL, ICON
+ { -- highlightToggled FULL, ICON
type = 'checkbox',
name = L.DisplayFrame_Highlight,
tooltip = L.DisplayFrame_HighlightTip,
@@ -1784,15 +1784,29 @@ tabPanelData = {
end,
hideOnStyle = {[AURA_STYLE_FULL] = false, [AURA_STYLE_ICON] = false, [AURA_STYLE_MINI] = true}
},
+ { -- enableTooltips ICON
+ type = 'checkbox',
+ name = L.DisplayFrame_Tooltips,
+ tooltip = L.DisplayFrame_TooltipsTip,
+ warning = L.DisplayFrame_TooltipsWarn,
+ getFunc = function()
+ return displayDB[currentDisplayFrame].enableTooltips
+ end,
+ setFunc = function(v)
+ displayDB[currentDisplayFrame].enableTooltips = v
+ Srendarr.displayFrames[currentDisplayFrame]:ConfigureAssignedAuras()
+ end,
+ hideOnStyle = {[AURA_STYLE_FULL] = true, [AURA_STYLE_ICON] = false, [AURA_STYLE_MINI] = true}
+ },
-- -----------------------
-- ABILITY TEXT SETTINGS
-- -----------------------
- [10] = { -- nameHeader FULL, MINI
+ { -- nameHeader FULL, MINI
type = 'header',
name = L.DisplayFrame_NameHeader,
hideOnStyle = {[AURA_STYLE_FULL] = false, [AURA_STYLE_ICON] = true, [AURA_STYLE_MINI] = false}
},
- [11] = { -- nameFont FULL, MINI
+ { -- nameFont FULL, MINI
type = 'dropdown',
name = L.GenericSetting_NameFont,
choices = LMP:List('font'),
@@ -1805,7 +1819,7 @@ tabPanelData = {
end,
hideOnStyle = {[AURA_STYLE_FULL] = false, [AURA_STYLE_ICON] = true, [AURA_STYLE_MINI] = false}
},
- [12] = { -- nameStyle FULL, MINI
+ { -- nameStyle FULL, MINI
type = 'dropdown',
name = L.GenericSetting_NameStyle,
choices = dropFontStyle,
@@ -1818,7 +1832,7 @@ tabPanelData = {
end,
hideOnStyle = {[AURA_STYLE_FULL] = false, [AURA_STYLE_ICON] = true, [AURA_STYLE_MINI] = false}
},
- [13] = { -- nameColour FULL, MINI
+ { -- nameColour FULL, MINI
type = 'colorpicker',
getFunc = function()
return unpack(displayDB[currentDisplayFrame].nameColour)
@@ -1834,7 +1848,7 @@ tabPanelData = {
widgetPositionAndResize = -15,
hideOnStyle = {[AURA_STYLE_FULL] = false, [AURA_STYLE_ICON] = true, [AURA_STYLE_MINI] = false}
},
- [14] = { -- nameSize FULL, MINI
+ { -- nameSize FULL, MINI
type = 'slider',
name = L.GenericSetting_NameSize,
min = 8,
@@ -1851,12 +1865,12 @@ tabPanelData = {
-- -----------------------
-- TIMER TEXT SETTINGS
-- -----------------------
- [15] = { -- timerHeader FULL, ICON, MINI
+ { -- timerHeader FULL, ICON, MINI
type = 'header',
name = L.DisplayFrame_TimerHeader,
hideOnStyle = {[AURA_STYLE_FULL] = false, [AURA_STYLE_ICON] = false, [AURA_STYLE_MINI] = false}
},
- [16] = { -- timerFont FULL, ICON, MINI
+ { -- timerFont FULL, ICON, MINI
type = 'dropdown',
name = L.GenericSetting_TimerFont,
choices = LMP:List('font'),
@@ -1869,7 +1883,7 @@ tabPanelData = {
end,
hideOnStyle = {[AURA_STYLE_FULL] = false, [AURA_STYLE_ICON] = false, [AURA_STYLE_MINI] = false}
},
- [17] = { -- timerStyle FULL, ICON, MINI
+ { -- timerStyle FULL, ICON, MINI
type = 'dropdown',
name = L.GenericSetting_TimerStyle,
choices = dropFontStyle,
@@ -1882,7 +1896,7 @@ tabPanelData = {
end,
hideOnStyle = {[AURA_STYLE_FULL] = false, [AURA_STYLE_ICON] = false, [AURA_STYLE_MINI] = false}
},
- [18] = { -- timerColour FULL, ICON, MINI
+ { -- timerColour FULL, ICON, MINI
type = 'colorpicker',
getFunc = function()
return unpack(displayDB[currentDisplayFrame].timerColour)
@@ -1898,7 +1912,7 @@ tabPanelData = {
widgetPositionAndResize = -15,
hideOnStyle = {[AURA_STYLE_FULL] = false, [AURA_STYLE_ICON] = false, [AURA_STYLE_MINI] = false}
},
- [19] = { -- timerSize FULL, ICON, MINI
+ { -- timerSize FULL, ICON, MINI
type = 'slider',
name = L.GenericSetting_TimerSize,
min = 8,
@@ -1912,7 +1926,7 @@ tabPanelData = {
end,
hideOnStyle = {[AURA_STYLE_FULL] = false, [AURA_STYLE_ICON] = false, [AURA_STYLE_MINI] = false}
},
- [20] = { -- timerLocation FULL
+ { -- timerLocation FULL
type = 'dropdown',
name = L.DisplayFrame_TimerLocation,
tooltip = L.DisplayFrame_TimerLocationTip,
@@ -1926,7 +1940,7 @@ tabPanelData = {
end,
hideOnStyle = {[AURA_STYLE_FULL] = false, [AURA_STYLE_ICON] = true, [AURA_STYLE_MINI] = true}
},
- [21] = { -- timerLocation ICON
+ { -- timerLocation ICON
type = 'dropdown',
name = L.DisplayFrame_TimerLocation,
tooltip = L.DisplayFrame_TimerLocationTip,
@@ -1943,12 +1957,12 @@ tabPanelData = {
-- -----------------------
-- STATUSBAR SETTINGS
-- -----------------------
- [22] = { -- barHeader FULL, MINI
+ { -- barHeader FULL, MINI
type = 'header',
name = L.DisplayFrame_BarHeader,
hideOnStyle = {[AURA_STYLE_FULL] = false, [AURA_STYLE_ICON] = true, [AURA_STYLE_MINI] = false}
},
- [23] = { -- barReverse FULL, MINI
+ { -- barReverse FULL, MINI
type = 'checkbox',
name = L.DisplayFrame_BarReverse,
tooltip = L.DisplayFrame_BarReverseTip,
@@ -1962,7 +1976,7 @@ tabPanelData = {
end,
hideOnStyle = {[AURA_STYLE_FULL] = false, [AURA_STYLE_ICON] = true, [AURA_STYLE_MINI] = false}
},
- [24] = { -- barGloss FULL, MINI
+ { -- barGloss FULL, MINI
type = 'checkbox',
name = L.DisplayFrame_BarGloss,
tooltip = L.DisplayFrame_BarGlossTip,
@@ -1975,7 +1989,7 @@ tabPanelData = {
end,
hideOnStyle = {[AURA_STYLE_FULL] = false, [AURA_STYLE_ICON] = true, [AURA_STYLE_MINI] = false}
},
- [25] = { -- barWidth FULL, MINI
+ { -- barWidth FULL, MINI
type = 'slider',
name = L.DisplayFrame_BarWidth,
tooltip = L.DisplayFrame_BarWidthTip,
@@ -1992,7 +2006,7 @@ tabPanelData = {
end,
hideOnStyle = {[AURA_STYLE_FULL] = false, [AURA_STYLE_ICON] = true, [AURA_STYLE_MINI] = false}
},
- [26] = { -- barColour[TIMED]:2 FULL, MINI
+ { -- barColour[TIMED]:2 FULL, MINI
type = 'colorpicker',
name = L.DisplayFrame_BarTimed,
tooltip = L.DisplayFrame_BarTimedTip,
@@ -2009,7 +2023,7 @@ tabPanelData = {
widgetRightAlign = true,
hideOnStyle = {[AURA_STYLE_FULL] = false, [AURA_STYLE_ICON] = true, [AURA_STYLE_MINI] = false}
},
- [27] = { -- barColour[TIMED]:1 FULL, MINI
+ { -- barColour[TIMED]:1 FULL, MINI
type = 'colorpicker',
tooltip = L.DisplayFrame_BarTimedTip,
getFunc = function()
@@ -2026,7 +2040,7 @@ tabPanelData = {
widgetPositionAndResize = 127,
hideOnStyle = {[AURA_STYLE_FULL] = false, [AURA_STYLE_ICON] = true, [AURA_STYLE_MINI] = false}
},
- [28] = { -- barColour[TOGGLED]:2 FULL, MINI
+ { -- barColour[TOGGLED]:2 FULL, MINI
type = 'colorpicker',
name = L.DisplayFrame_BarToggled,
tooltip = L.DisplayFrame_BarToggledTip,
@@ -2043,7 +2057,7 @@ tabPanelData = {
widgetRightAlign = true,
hideOnStyle = {[AURA_STYLE_FULL] = false, [AURA_STYLE_ICON] = true, [AURA_STYLE_MINI] = false}
},
- [29] = { -- barColour[TOGGLED]:1 FULL, MINI
+ { -- barColour[TOGGLED]:1 FULL, MINI
type = 'colorpicker',
tooltip = L.DisplayFrame_BarToggledTip,
getFunc = function()
@@ -2060,7 +2074,7 @@ tabPanelData = {
widgetPositionAndResize = 127,
hideOnStyle = {[AURA_STYLE_FULL] = false, [AURA_STYLE_ICON] = true, [AURA_STYLE_MINI] = false}
},
- [30] = { -- barColour[PASSIVE]:2 FULL, MINI
+ { -- barColour[PASSIVE]:2 FULL, MINI
type = 'colorpicker',
name = L.DisplayFrame_BarPassive,
tooltip = L.DisplayFrame_BarPassiveTip,
@@ -2077,7 +2091,7 @@ tabPanelData = {
widgetRightAlign = true,
hideOnStyle = {[AURA_STYLE_FULL] = false, [AURA_STYLE_ICON] = true, [AURA_STYLE_MINI] = false}
},
- [31] = { -- barColour[PASSIVE]:1 FULL, MINI
+ { -- barColour[PASSIVE]:1 FULL, MINI
type = 'colorpicker',
tooltip = L.DisplayFrame_BarPassiveTip,
getFunc = function()